<?php include('db_connect.php') ?>
<!-- Chart.js -->
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script src="https://cdn.jsdelivr.net/npm/chartjs-plugin-datalabels"></script>

<?php
$anio_actual = date('Y');
$anio_seleccionado = isset($_GET['anio']) ? (int)$_GET['anio'] : $anio_actual;

// Obtener conteo de encuestas por mes del año seleccionado
$meses = [];
$conteos = [];
$encuestas_completadas = [];

for ($i = 1; $i <= 12; $i++) {
  $nombre_mes = date('F', mktime(0, 0, 0, $i, 10));
  $meses[] = $nombre_mes;
  $inicio_mes = "$anio_seleccionado-" . str_pad($i, 2, '0', STR_PAD_LEFT) . "-01";
  $fin_mes = "$anio_seleccionado-" . str_pad($i, 2, '0', STR_PAD_LEFT) . "-31";
  
  // Conteo de encuestas por mes
  $sql = "SELECT COUNT(*) AS total FROM survey_set WHERE date(start_date) BETWEEN '$inicio_mes' AND '$fin_mes'";
  $res = $conn->query($sql)->fetch_assoc();
  $conteos[] = $res['total'];
  
  // Conteo de encuestas completadas por mes
  $sql_completadas = "SELECT COUNT(*) AS total_completadas FROM survey_set WHERE date(end_date) BETWEEN '$inicio_mes' AND '$fin_mes'";
  $res_completadas = $conn->query($sql_completadas)->fetch_assoc();
  $encuestas_completadas[] = $res_completadas['total_completadas'];
}
?>

<?php if ($_SESSION['login_type'] == 1) : ?>
  <div class="row">
    <div class="col-12 col-sm-6 col-md-3">
      <div class="info-box">
        <span class="info-box-icon bg-info elevation-1"><i class="fas fa-users"></i></span>
        <div class="info-box-content">
          <span class="info-box-text">Total de Usuarios</span>
          <span class="info-box-number">
  <?php echo $conn->query("SELECT * FROM users WHERE type IN (2, 3)")->num_rows; ?>
</span>
        </div>
      </div>
    </div>
    <div class="col-12 col-sm-6 col-md-3">
      <div class="info-box mb-3">
        <span class="info-box-icon bg-primary elevation-1"><i class="fas fa-poll-h"></i></span>
        <div class="info-box-content">
          <span class="info-box-text">Total de Encuestas</span>
          <span class="info-box-number">
            <?php echo $conn->query("SELECT * FROM survey_set")->num_rows; ?>
          </span>
        </div>
      </div>
    </div>
  </div>

  <!-- Filtro de año -->
  <div class="row mb-3">
    <div class="col-md-6 offset-md-6">
      <form method="GET" id="filtro-anio-form" class="form-inline justify-content-end">
        <label for="anio" class="mr-2">Año:</label>
        <select name="anio" id="anio" class="form-control" onchange="document.getElementById('filtro-anio-form').submit()">
          <?php for ($i = $anio_actual; $i >= $anio_actual - 4; $i--) : ?>
            <option value="<?php echo $i; ?>" <?php echo $anio_seleccionado == $i ? 'selected' : ''; ?>>
              <?php echo $i; ?>
            </option>
          <?php endfor; ?>
        </select>
      </form>
    </div>
  </div>

  <!-- Gráficos -->
  <div class="row mt-4">
    <!-- Gráfico Doughnut -->
    <div class="col-md-6">
      <div class="card">
        <div class="card-header">Encuestas Activas vs Finalizadas</div>
        <div class="card-body text-center">
          <div style="max-width: 300px; margin: auto;">
            <canvas id="surveyChart" height="250"></canvas>
          </div>
        </div>
      </div>
    </div>

    <!-- Gráfico de Barras -->
    <div class="col-md-6">
      <div class="card">
        <div class="card-header">Encuestas por Mes (<?php echo $anio_seleccionado; ?>)</div>
        <div class="card-body">
          <canvas id="monthlyChart" height="250"></canvas>
        </div>
      </div>
    </div>
  </div>

  <!-- Gráfico de Tendencia (Línea) -->
  <div class="row mt-4">
    <div class="col-md-12">
      <div class="card">
        <div class="card-header">Tendencia de Encuestas Completadas (<?php echo $anio_seleccionado; ?>)</div>
        <div class="card-body">
          <canvas id="trendChart" height="250"></canvas>
        </div>
      </div>
    </div>
  </div>

  <!-- Scripts de gráficos -->
  <script>
    document.addEventListener('DOMContentLoaded', function () {
      // Doughnut
      const ctx = document.getElementById('surveyChart').getContext('2d');
      new Chart(ctx, {
        type: 'doughnut',
        data: {
          labels: ['Activas', 'Finalizadas'],
          datasets: [{
            data: [
              <?php echo $conn->query("SELECT * FROM survey_set WHERE NOW() BETWEEN start_date AND end_date")->num_rows; ?>,
              <?php echo $conn->query("SELECT * FROM survey_set WHERE NOW() > end_date")->num_rows; ?>
            ],
            backgroundColor: ['#007bff', '#6c757d']
          }]
        },
        options: {
          responsive: true,
          maintainAspectRatio: false,
          plugins: {
            legend: {
              position: 'bottom'
            },
            datalabels: {
              formatter: function (value, ctx) {
                let total = 0;
                ctx.chart.data.datasets[0].data.forEach(function (element) {
                  total += element;
                });
                let porcentaje = ((value / total) * 100).toFixed(1); // Calcula el porcentaje
                return value + ' (' + porcentaje + '%)'; // Muestra número y porcentaje
              },
              color: '#fff',
              font: {
                weight: 'bold',
                size: 14
              }
            }
          }
        }
      });

      // Bar Chart
      const bar = document.getElementById('monthlyChart').getContext('2d');
      new Chart(bar, {
        type: 'bar',
        data: {
          labels: <?php echo json_encode($meses); ?>,
          datasets: [{
            label: 'Encuestas',
            data: <?php echo json_encode($conteos); ?>,
            backgroundColor: '#17a2b8'
          }]
        },
        options: {
          responsive: true,
          maintainAspectRatio: false,
          scales: {
            y: {
              beginAtZero: true
            }
          }
        }
      });

      // Trend Line Chart (Tendencia de Encuestas Completadas)
      const trend = document.getElementById('trendChart').getContext('2d');
      new Chart(trend, {
        type: 'line',
        data: {
          labels: <?php echo json_encode($meses); ?>,
          datasets: [{
            label: 'Encuestas Completadas',
            data: <?php echo json_encode($encuestas_completadas); ?>,
            borderColor: '#28a745',
            backgroundColor: 'rgba(40, 167, 69, 0.2)',
            fill: true
          }]
        },
        options: {
          responsive: true,
          maintainAspectRatio: false,
          scales: {
            y: {
              beginAtZero: true
            }
          }
        }
      });
    });
  </script>

  <style>
    canvas {
      max-height: 250px !important;
    }
    .card {
      border-radius: 10px;
    }
  </style>

<?php else : ?>
  <div class="col-12">
    <div class="card">
      <div class="card-body">
        Hola de Nuevo <?php echo $_SESSION['login_name'] ?>!
      </div>
    </div>
  </div>
  <div class="row">
    <div class="col-12 col-sm-6 col-md-3">
      <div class="info-box">
        <span class="info-box-icon bg-primary elevation-1"><i class="fas fa-poll-h"></i></span>
        <div class="info-box-content">
          <span class="info-box-text">Encuestas Tomadas</span>
          <span class="info-box-number">
            <?php echo $conn->query("SELECT DISTINCT(survey_id) FROM answers WHERE user_id = {$_SESSION['login_id']}")->num_rows; ?>
          </span>
        </div>
      </div>
    </div>
  </div>
<?php endif; ?>
